@@ -388,8 +388,8 @@ class Imagine:
                         img=img,
                         prompt=prompt,
                         upscaled_img=upscaled_img,
-                        is_nsfw=safety_score.is_nsfw,
-                        safety_score=safety_score,
+                        is_nsfw=False if self.nsfw_filter is False else safety_score.is_nsfw,
+                        safety_score=None if self.nsfw_filter is False else safety_score,
                         modified_original=rebuilt_orig_img,
                         mask_binary=mask_image_orig,
                         mask_grayscale=mask_grayscale,
